@@ -1,5 +1,7 @@
 from allianceauth.services.hooks import get_extension_logger
 
+from buybackprogram.app_settings import BUYBACKPROGRAM_PRICE_SOURCE_NAME
+
 logger = get_extension_logger(__name__)
 
 
@@ -8,7 +10,8 @@ def note_missing_jita_buy(buy_price, name):
         note = {
             "icon": "fa-question",
             "color": "red",
-            "message": "%s has no buy orders in jita" % name,
+            "message": "%s has no buy orders in %s"
+            % (name, BUYBACKPROGRAM_PRICE_SOURCE_NAME),
         }
         return note
     else:
@@ -20,8 +23,8 @@ def note_price_dencity_tax(name, price_dencity, price_dencity_tax):
         note = {
             "icon": "fa-weight-hanging",
             "color": "orange",
-            "message": "%s has price dencity of %s isk/m³, %s %s low price dencity tax applied"
-            % (name, price_dencity, price_dencity_tax, "%"),
+            "message": "%s has price density of %s isk/m³, %s %s low price dencity tax applied"
+            % (name, round(price_dencity, 2), price_dencity_tax, "%"),
         }
 
         return note
@@ -124,6 +127,16 @@ def note_npc_price(name):
     note = {
         "icon": "fa-robot",
         "color": "#5858df",
-        "message": "Using NPC buy price for %s instead of Jita buy prices" % name,
+        "message": "Using NPC buy price for %s instead of %s buy prices"
+        % (name, BUYBACKPROGRAM_PRICE_SOURCE_NAME),
+    }
+    return note
+
+
+def note_raw_price_used(name):
+    note = {
+        "icon": "fa-icicles",
+        "color": "#5858df",
+        "message": "Best price: Using raw price for %s" % name,
     }
     return note
